==> ejc-xmgs-impl-3.0.0-20220629.014409-2-sources.jar: com/ejianc/business/xmgs/vo/WorkTimeDetailVO.java <==
package com.ejianc.business.xmgs.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 工时管理明细
 * 
 * @author generator
 * 
 */
public class WorkTimeDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long wtId; // 主表主键
    private String createUserName; // 创建人名称
    private Long projectId; // 项目主键
    private String projectName; // 项目名称
    private BigDecimal workTime; // 工时
    private String workDetail; // 工作内容
    

    public Long getWtId() {
        return wtId;
    }

    public void setWtId(Long wtId) {
        this.wtId = wtId;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public BigDecimal getWorkTime() {
        return workTime;
    }

    public void setWorkTime(BigDecimal workTime) {
        this.workTime = workTime;
    }
    public String getWorkDetail() {
        return workDetail;
    }

    public void setWorkDetail(String workDetail) {
        this.workDetail = workDetail;
    }
    
}

==> ejc-xmgs-impl-3.0.0-20240218.072430-21-sources.jar: com/ejianc/business/xmgs/vo/WorkTimeDetailVO.java <==
package com.ejianc.business.xmgs.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 工时管理明细
 *
 * @author generator
 *
 */
public class WorkTimeDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long wtId; // 主表主键
    private Long projectId; // 项目主键
    private String projectName; // 项目名称
    private BigDecimal workTime; // 工时
    private String workDetail; // 工作内容


    public Long getWtId() {
        return wtId;
    }

    public void setWtId(Long wtId) {
        this.wtId = wtId;
    }
    @ReferSerialTransfer(referCode="xmgs-project")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public BigDecimal getWorkTime() {
        return workTime;
    }

    public void setWorkTime(BigDecimal workTime) {
        this.workTime = workTime;
    }
    public String getWorkDetail() {
        return workDetail;
    }

    public void setWorkDetail(String workDetail) {
        this.workDetail = workDetail;
    }

}
